export interface RowVO {
    id: number;
    sysName: string;
    energyStationName: string;
    controlModel: number;
}


export const tableCloumn = [
    { field: 'energyStationName', title: '换热站', width: 120, fixed: 'left' },
    { field: 'sysName', title: '系统名称', width: 80, fixed: 'left' },
    { field: '_id', title: '系统编号', width: 100 },
    {
        field: 'controlModel', title: '控制模式', width: 100, formatter: ({ cellValue, row }) => {
            if (!cellValue) return null
            if (String(cellValue) === '1') {
                return '设定'
            } else if (String(cellValue) === '2') {
                return '计算'
            } else {
                return '手动'
            }
        }
    },
    { field: 'startTemperature', title: '起始温度', width: 100, visible: false },
    { field: 'mbwd', title: '目标温度', width: 100, visible: false },
    { field: 'outdoorTemp', title: '室外温度', width: 100 },
    {
        title: '一次',
        children: [
            {
                field: 'ycgswd',
                title: '供温',
                width: 100,
            },
            {
                field: 'ychswd',
                title: '回温',
                width: 100,
            },
            {
                field: 'ycwdc',
                title: '温差',
                width: 100
            },
            {
                field: 'ycgsyl',
                title: '供压',
                width: 100,
            },
            {
                field: 'ychsyl',
                title: '回压',
                width: 100
            },
            {
                field: 'ycylc',
                title: '压差',
                width: 100
            },
        ],
    },
    { field: 'fmkd', title: '阀门开度', width: 100 },
    {
        title: '二次',
        children: [
            {
                field: 'ecgswd',
                title: '供温',
                width: 100
            },
            {
                field: 'echswd',
                title: '回温',
                width: 100,
            },
            {
                field: 'ecwdc',
                title: '温差',
                width: 100,
            },
            {
                field: 'ecgsyl',
                title: '供压',
                width: 100,
            },
            {
                field: 'echsyl',
                title: '回压',
                width: 100
            },
            {
                field: 'ecylc',
                title: '压差',
                width: 100
            },
        ],
    },
    { field: 'zsl', title: '总水量', width: 100 },
    { field: 'zdl', title: '总电量', width: 100 },
    { title: '操作', width: 220, fixed: 'right', slots: { default: 'operate' } }
]

// 初始化曲率数组
export const initCurvatureList = [{
    start: -50,
    end: 30,
    qulv: 0.5,
}]

/**初始化分时修正数组 */
export const initAmendmentList = [
    // 分时修正
    {
        startHour: '00',
        startMinute: '00',
        endHour: '23',
        endMinute: '59',
        value: 0,
    },
]

// 禁用指定时间
export const disableTime = (h) => {
    if (h < 1) {
        return {
            minute: [0],
        };
    }
    if (h > 22) {
        return {
            minute: [59],
        };
    }
}


/**截取指定字符前面或者后面的字符
 * obj参数 字符串
 * state 0 1 0代表前面1代码后面
*/

export function getCaption(obj, state) {
    var index = obj.lastIndexOf("\:");
    if (state == 0) {
        obj = obj.substring(0, index);
    } else {
        obj = obj.substring(index + 1, obj.length);
    }
    return obj;
}


